.. expect: inline literal missing (escaped) space after literal: '``Callable``s' (missing-space-after-literal)
.. expect: found an unbalanced inline literal markup. (unbalanced-inline-literals-delimiters)
.. expect: found an unbalanced inline literal markup. (unbalanced-inline-literals-delimiters)

Here ``Callable``s the "s" should be separated from ``Callable`` using
a "backslash-space".
